import { AbstractClass, DataObject, NewData } from './utility';
import { BaseListModel } from './Base';
export interface PageData<D extends DataObject> {
    pageData: D[];
    totalCount?: number;
}
export declare abstract class ListModel<D extends DataObject, F extends NewData<D> = NewData<D>> extends BaseListModel<D> {
    pageIndex: number;
    pageSize: number;
    filter: F;
    totalCount: number;
    pageList: D[][];
    get currentPage(): D[];
    get allItems(): any[];
    get noMore(): boolean;
    constructor();
    clear(): this;
    restoreList(allItems?: any[], pageSize?: number, totalCount?: number): void;
    turnTo(pageIndex: number, pageSize?: number): this;
    abstract loadPage(pageIndex: number, pageSize: number, filter: F): Promise<PageData<D>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: F): Promise<{
        pageData: D[];
        totalCount: number;
    }>;
    getList(filter?: F, pageIndex?: number, pageSize?: number): Promise<D[]>;
}
export declare function Buffer<D extends DataObject, F extends NewData<D> = NewData<D>, M extends AbstractClass<ListModel<D, F>> = AbstractClass<ListModel<D, F>>>(Super: M): (abstract new (...data: any[]) => {
    pendingList: ReturnType<ListModel<D, F>['loadPage']>[];
    clear(): any;
    getList(filter?: F, pageIndex?: number, pageSize?: number): Promise<D[]>;
    pageIndex: number;
    pageSize: number;
    filter: F;
    totalCount: number;
    pageList: D[][];
    readonly currentPage: D[];
    readonly allItems: any[];
    readonly noMore: boolean;
    restoreList(allItems?: any[], pageSize?: number, totalCount?: number): void;
    turnTo(pageIndex: number, pageSize?: number): any;
    loadPage(pageIndex: number, pageSize: number, filter: F): Promise<PageData<D>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: F): Promise<{
        pageData: D[];
        totalCount: number;
    }>;
    client: import("./utility").RESTClient;
    baseURI: string;
    currentOne: D;
    validity: Partial<Record<keyof D, {
        [type: string]: string;
    }>>;
    updateOne(data: Partial<Omit<D, import("web-utility").TypeKeys<D, DataObject> | import("web-utility").TypeKeys<D, DataObject[]>> & { [K in import("web-utility").TypeKeys<D, DataObject>]: import("./utility").IDType; } & { [K_1 in import("web-utility").TypeKeys<D, DataObject[]>]: import("./utility").IDType[]; }>, id?: import("./utility").IDType): Promise<D>;
    getOne(id: import("./utility").IDType): Promise<D>;
    removeOne(id: import("./utility").IDType): Promise<void>;
    downloading: number;
    uploading: number;
}) & M;
export declare function Stream<D extends DataObject, F extends NewData<D> = NewData<D>, M extends AbstractClass<ListModel<D, F>> = AbstractClass<ListModel<D, F>>>(Super: M): (abstract new (...data: any[]) => {
    baseURI: string;
    stream?: AsyncGenerator<D, void, any>;
    openStream(filter: F): AsyncGenerator<D, void, any>;
    clear(): any;
    restoreList(allItems?: any[], pageSize?: number, totalCount?: number): Promise<void>;
    loadStream(filter: F, newCount: number): Promise<D[]>;
    loadPage(pageIndex: number, pageSize: number, filter: F): Promise<{
        pageData: D[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: F;
    totalCount: number;
    pageList: D[][];
    readonly currentPage: D[];
    readonly allItems: any[];
    readonly noMore: boolean;
    turnTo(pageIndex: number, pageSize?: number): any;
    loadNewPage(pageIndex: number, pageSize: number, filter: F): Promise<{
        pageData: D[];
        totalCount: number;
    }>;
    getList(filter?: F, pageIndex?: number, pageSize?: number): Promise<D[]>;
    client: import("./utility").RESTClient;
    currentOne: D;
    validity: Partial<Record<keyof D, {
        [type: string]: string;
    }>>;
    updateOne(data: Partial<Omit<D, import("web-utility").TypeKeys<D, DataObject> | import("web-utility").TypeKeys<D, DataObject[]>> & { [K in import("web-utility").TypeKeys<D, DataObject>]: import("./utility").IDType; } & { [K_1 in import("web-utility").TypeKeys<D, DataObject[]>]: import("./utility").IDType[]; }>, id?: import("./utility").IDType): Promise<D>;
    getOne(id: import("./utility").IDType): Promise<D>;
    removeOne(id: import("./utility").IDType): Promise<void>;
    downloading: number;
    uploading: number;
}) & M;
